@@ -4,7 +4,8 @@ import unittest
 
 from slugify import Slugify
 from slugify import slugify, slugify_unicode
-from slugify import slugify_ru, slugify_de
+from slugify import slugify_ru, slugify_de, slugify_el
+
 from slugify import get_slugify
 
 
@@ -34,14 +35,33 @@ class SlugifyTestCase(unittest.TestCase):
     def test_slugify_ru(self):
         self.assertEqual(slugify_ru('Компьютер'), 'Komputer')
         self.assertEqual(slugify_ru('Транслитерирует и русский'), 'Transliteriryet-i-rysskii')
-        self.assertEqual(slugify_ru('ёжик из щуки сварил уху'), 'ejik-iz-schyki-svaril-yhy')
+        self.assertEqual(slugify_ru('ёжик из щуки сварил уху'), 'ezhik-iz-schyki-svaril-yhy')
         self.assertEqual(slugify_ru('Ах, Юля-Юля'), 'Ah-Ulya-Ulya')
 
+    def test_greek(self):
+        self.assertEqual(slugify_el('ϒ Ϋ υ ϋ ΰ'), 'Y-Y-y-y-y')
+
     def test_slugify_unicode(self):
         self.assertEqual(slugify_unicode('-=Слово по-русски=-'), u'Слово-по-русски')
         self.assertEqual(slugify_unicode('слово_по_русски'), u'слово-по-русски')
 
 
+class ToLowerTestCase(unittest.TestCase):
+
+    def test_to_lower(self):
+        self.assertEqual(slugify('Test TO lower', to_lower=True), 'test-to-lower')
+
+    def test_to_lower_arg(self):
+        slugify = Slugify()
+        slugify.to_lower = True
+
+        self.assertEqual(slugify('Test TO lower'), 'test-to-lower')
+        self.assertEqual(slugify('Test TO lower', to_lower=False), 'Test-TO-lower')
+
+    def test_to_lower_with_capitalize(self):
+        self.assertEqual(slugify('Test TO lower', to_lower=True, capitalize=True), 'Test-to-lower')
+
+
 class UpperTestCase(unittest.TestCase):
     def test_full_upper(self):
         self.assertEqual(slugify_ru('ЯНДЕКС'), 'YANDEKS')
@@ -100,6 +120,25 @@ class PretranslateTestCase(unittest.TestCase):
         self.assertRaises(ValueError, lambda: Slugify(pretranslate={1, 2}))
 
 
+class SanitizeTestCase(unittest.TestCase):
+    def test_sanitize(self):
+        self.assertEqual(slugify('test_sanitize'), 'test-sanitize')
+
+    def test_safe_chars(self):
+        slugify = Slugify()
+
+        slugify.safe_chars = '_'
+        self.assertEqual(slugify('test_sanitize'), 'test_sanitize')
+
+        slugify.safe_chars = "'"
+        self.assertEqual(slugify('Конь-Огонь'), "Kon'-Ogon'")
+
+    def test_filename_slugify(self):
+        filename_slugify = Slugify(safe_chars='-_.', separator='_')
+        self.assertEqual(filename_slugify(u'Дrаft №2.txt'), u'Draft_2.txt')
+        # self.assertEqual(filename_slugify(u'Дrаft №2.txt'), u'Draft_No2.txt')
+
+
 class TruncateTestCase(unittest.TestCase):
 
     def test_truncate(self):
@@ -133,7 +172,7 @@ class TruncateTestCase(unittest.TestCase):
 
 class OtherTestCase(unittest.TestCase):
 
-    def test_prevent_double_translation(self):
+    def test_prevent_double_pretranslation(self):
         slugify = Slugify(pretranslate={'s': 'ss'})
         self.assertEqual(slugify('BOOST'), 'BOOSST')
 
@@ -143,10 +182,6 @@ class OtherTestCase(unittest.TestCase):
     def test_capitalize_on_empty(self):
         self.assertEqual(slugify('', capitalize=True), '')
 
-    def test_safe_chars(self):
-        filename_slugify = Slugify(safe_chars='-_.', separator='_')
-        self.assertEqual(filename_slugify(u'Дrаft №2.txt'), u'Draft_2.txt')
-
 
 class DeprecationTestCase(unittest.TestCase):
 
